/*
 * Copyright (C) 2009 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.SampleIrdaIrss;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.AdapterView.OnItemClickListener;

/**
 * 赤外線メイン画面のアクティビティである。
 * 赤外線の送信／受信をリストで表示し、リスト上で選択した機能のアクティビティを呼び出す。
 * 送信：SampleIrdaIrssSendActivity
 * 受信：SampleIrdaIrssReceiveActivity
 */
public class SampleIrdaIrssMainActivity extends Activity {
    private static final Class<?> TRANSITION_CLASS[] = {
        SampleIrdaIrssSendActivity.class, SampleIrdaIrssReceiveActivity.class
    };

    /**
     *  アクティビティ作成時に呼ばれるメソッドである。
     *  リストビューにアダプタとクリックリスナの設定を行う。
     */    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        setTitle(R.string.sample_irda_name);

        /* リストビュー取得 */
        ListView listView = (ListView)findViewById(R.id.irda_list);
        /* アダプタ作成 */
        ArrayAdapter<String> arrayAdapter = new ArrayAdapter<String>(this,
                android.R.layout.simple_list_item_1,
                getResources().getStringArray(R.array.sample_irda_listItem));
        /* リストビューにアダプタを設定 */
        listView.setAdapter(arrayAdapter);
        /* クリックリスナを作成 */
        listView.setOnItemClickListener(new MyClickAdapter());
    }

     /**
      * クリックリスナを実装したクラスである。
      * リストが選択された時にonItemClickを呼ぶ。
      * 選択された位置はpositionによって通知される。
      * positionの値に応じたアクティビティを起動する。
      */
    class MyClickAdapter implements OnItemClickListener {
        public void onItemClick(AdapterView<?> adapter,
            View view, int position, long id) {
            try {
                /* インテント作成 */
                Intent intent =new Intent(SampleIrdaIrssMainActivity.this,
                        TRANSITION_CLASS[position]);
                /* アクティビティを起動 */
                startActivity(intent);
            } catch (ArrayIndexOutOfBoundsException e) {
                e.printStackTrace();
            }
        }
    }

}