/*
 * Copyright (C) 2009 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android.SampleIrdaIrss;

import java.io.File;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.os.Environment;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import jp.co.sharp.android.io.obex.server.PushServer;


/**
 * 赤外線受信のアクティビティである。
 * PushServer APIを使用して赤外線でファイルの受信を行う。
 */
public class SampleIrdaIrssReceiveActivity extends Activity {

    ProgressDialog mProgressDialog = null;
    PushServer mPushServer = null;

    /**
     *  アクティビティ作成時に呼ばれるメソッドである。
     *  ボタンのクリックリスナの設定を行う。
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.sample_irda_irss_receive);

        /* ボタンにクリックリスナを設定 */
        Button btn = (Button)findViewById(R.id.receive_start);
        btn.setOnClickListener(new OnClickListener() {
            /**
             * ボタンを押したときに呼ばれるメソッドである。
             */
            public void onClick(View view) {
                /* 進捗ダイアログ表示 */
                showProgress();
                /* 受信 */
                receiving();
            }
        });

    }

    @Override
    protected void onStop() {
        super.onStop();

        /* 通信中にアクティビティが停止した場合、受信を中断する。 */
        if (mPushServer != null) {
            mPushServer.disconnect();    /* ★Addon用API使用箇所★ */
            mPushServer = null;
        }
        /* 通信中にアクティビティが停止した場合、進捗ダイアログを閉じる。 */
        if (mProgressDialog != null) {
            mProgressDialog.dismiss();
        }

    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if(mBroadcastReceiver.getDebugUnregister()) {
            unregisterReceiver(mBroadcastReceiver);
        }
    }

    /**
     * 進捗ダイアログの表示を行うメソッドである。
     */
    private void showProgress() {
         /* 進捗ダイアログ作成 */
        mProgressDialog = new ProgressDialog(this);
        /* タイトル設定 */
        mProgressDialog.setTitle(R.string.sample_irda_title);
        /* メッセージ設定 */
        mProgressDialog.setMessage(getResources().getString(R.string.sample_irda_wait));
        /* 戻るボタン無効 */
        mProgressDialog.setCancelable(false);
        /* 円型に設定 */
        mProgressDialog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
        /* ボタン追加 */
        mProgressDialog.setButton(DialogInterface.BUTTON_NEUTRAL, getResources().getString(R.string.sample_irda_cancel),
                new DialogInterface.OnClickListener() {
            /**
             * ボタンが押されたときに呼ばれるメソッドである。
             */
            public void onClick(DialogInterface dialog, int whichButton) {
                if (mPushServer != null) {
                    mPushServer.disconnect();    /* ★Addon用API使用箇所★ */
                    mPushServer = null;
                }
                mProgressDialog.dismiss();
            }
        });
        mProgressDialog.show();
    }

    /**
     * 受信の設定を行うメソッドである。
     * インテントフィルタに取得するアクションを設定し、ブロードキャストレシーバーに登録する。
     */
    public void receiving() {
        /* インテントフィルタ作成 */
        IntentFilter filter = new IntentFilter();
        /* インテントフィルタ設定 */
        filter.addAction(PushServer.CONNECTION_STATUS);
        filter.addAction(PushServer.PUT_STARTED);
        filter.addAction(PushServer.PUT_PROGRESS);
        filter.addAction(PushServer.PUT_FINISHED);
        /* ブロードキャストレシーバに登録 */
        registerReceiver(mBroadcastReceiver, filter);
        mBroadcastReceiver.setDebugUnregister(true);

        /* 受信クラス作成 */
        mPushServer = new PushServer();
        /* 接続待ち開始 */
        mPushServer.connect(PushServer.TYPE_AUTO);    /* ★Addon用API使用箇所★ */
    }

    /**
     * ブロードキャストレシーバークラスである。
     * 登録したアクションがブロードキャストされたときにonReceiveが呼ばれる。
     * 接続状態、受信開始、受信中、受信終了を受け取る。
     */
    private BroadcastReceiver mBroadcastReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            /* アクション取得 */
            String action = intent.getAction();
            /* アクションにより、処理を分岐 */
            if (action.equals(PushServer.CONNECTION_STATUS)) {
                /* 接続状態 */
                int status = intent.getIntExtra("status", PushServer.STATUS_NOT_CONNECTED);
                int result = intent.getIntExtra("result", PushServer.RESULT_ERROR_OTHER);
                if (status == PushServer.STATUS_NOT_CONNECTED) {
                    if (result == PushServer.RESULT_SUCCESS) {
                        /* 受信が終了し、切断完了 */
                    } else {
                        /* エラー終了 */
                        /* 必要に応じてエラー処理を記述してください。 */
                        if (result == PushServer.RESULT_ERROR_DEVICE_DISCONNECTED) {
                            /* 接続相手が見つからずに切断された */
                            MessageDialog messageDialog = new MessageDialog();
                            if (mPushServer != null) {
                                messageDialog.show(context, R.string.sample_irda_connect_failed);
                            }
                        }
                    }
                    mProgressDialog.dismiss();
                    mPushServer = null;
                } else {
                    /* 接続完了 */
                }
            } else if (action.equals(PushServer.PUT_STARTED)) {
                /* 相手からの送信が開始されたので保存先ファイル名を指定する */
                String name = intent.getStringExtra("name");
                File file = Environment.getExternalStorageDirectory();
                String filepath = file.getPath() + "/" + name;
                Log.i("Test", filepath);
                mPushServer.accept(filepath);    /* ★Addon用API使用箇所★ */
            } else if (action.equals(PushServer.PUT_PROGRESS)) {
                /* 受信処理中。受信済みサイズを取得可能です。 */
            } else if (action.equals(PushServer.PUT_FINISHED)) {
                /* オブジェクトの受信終了です */
                int result = intent.getIntExtra("result",PushServer.RESULT_ERROR_OTHER);
                if (result == PushServer.RESULT_SUCCESS) {
                    /* 受信中のオブジェクトの受信に成功した */
                    MessageDialog messageDialog = new MessageDialog();
                    messageDialog.show(context, R.string.sample_irda_receive_success);
                } else {
                    /* 受信中のオブジェクトの受信に失敗した */
                    MessageDialog messageDialog = new MessageDialog();
                    messageDialog.show(context, R.string.sample_irda_receive_failed);
                }
            }
        }
   };

}